<?php
/**
 * Blog masonry
 *
 * @package minera
 */

// Display style: pagination | load more button | infinite scroll.
$style   = get_theme_mod( 'c_blog_style', 'pagi' );
$classes = 'pagi' != $style ? 'blog-data data-' . $style : '';

// Masonry script.
wp_enqueue_script( 'masonry' );

?>
<style>
	.custom-post-page{
		padding-bottom: 100px;
	}
	.custom-post-page .blog-article{
		border-bottom: 0;
		margin-bottom: 50px;
		padding-bottom: 0;
	}
	.custom-post-page .blog-post-info{
		margin-top: 24px;
		margin-bottom: 14px;
	}
	.custom-post-page .blog-post-sumary{
		margin-top: 23px;
	}
	.custom-post-page .btn-load-more-post,
	.custom-post-page .ht-pagination,
	.custom-post-page .el-loading{
		position: absolute;
		bottom: 0;
		left: 50%;
		transform: translateX( -50% );
		margin-left: 0;
		float: none;
	}
	.blog .custom-post-page .blog-article+.ht-pagination{
		border-top: 0;
		padding-top: 0;
	}
</style>

<div class="custom-post-page blog-news-masonry col-md-12 col-lg-12 <?php echo esc_attr( $classes ); ?>">
	<div class="gutter-sizer"></div>
	<?php
	if ( have_posts() ) :
		while ( have_posts() ) :
			the_post();

			$img_id            = get_post_thumbnail_id();
			$thumbnail_initial = get_the_post_thumbnail_url();
			$thumbnail         = function_exists( 'FW' ) ? fw_resize( $img_id, 370 ) : $thumbnail_initial;
			$img_alt           = minera_img_alt( $img_id, esc_attr__( 'Blog thumbnail', 'minera' ) );
			?>

			<div class="blog-article" itemscope itemtype="https://schema.org/Blog">
				<article id="post-<?php the_ID(); ?>" <?php post_class(); ?> itemscope itemtype="http://schema.org/BlogPosting">

					<?php if ( ! empty( $img_id ) ) : ?>
						<a href="<?php the_permalink(); ?>" class="blog-news-thumbnail">
							<img src="<?php echo esc_url( $thumbnail ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>" itemprop="image">
						</a>
					<?php endif; ?>

					<div class="post-content">
						<?php
							// Best for SEO.
							minera_structured_data();

							// Post meta.
							minera_post_info();
						?>

						<h2 class="pure-heading" itemprop="headline">
							<a class="blog-news-tit" href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
						</h2>

						<div class="blog-post-sumary" itemprop="description"><?php echo wp_trim_words( get_the_excerpt(), 28, '...' ); // WPCS xss: ok. ?></div>

						<a href="<?php the_permalink(); ?>" class="read-more">
							<?php esc_html_e( 'Read More', 'minera' ); ?>
							<span class="screen-reader-text"><?php esc_html_e( 'about an interesting article to read', 'minera' ); ?></span>
						</a>
					</div>
				</article>
			</div>
			<?php
		endwhile;

		if ( 'pagi' != $style ) {
			global $wp_query;
			$count = $wp_query->max_num_pages;

			if ( $count <= 1 ) {
				return;
			}

			/*load more button*/
			if ( 'btn' == $style ) {
				echo '<button class="btn-load-more-post">' . esc_html__( 'Load more posts', 'minera' ) . '</button>';
			} else {
				echo '<span class="el-loading">' . esc_html__( 'Scroll to load more post', 'minera' ) . '</span>';
			}
		} else {
			minera_paging();
		}
	else :
		get_template_part( 'content', 'none' );
	endif;
	?>
</div>
