<?php
/*Filters and Actions*/
if ( ! function_exists( 'minera_action_theme_setup' ) ) :
	function minera_action_theme_setup() {

		/*Make Theme available for translation*/
		load_theme_textdomain( 'minera', get_template_directory() . '/languages' );

		// Add RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'title-tag' );
	    add_theme_support( 'woocommerce' );

		/*Switch default core markup for search form, comment form, and comments to output valid HTML5.*/
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) );

		/*Enable support for Post Formats. See http://codex.wordpress.org/Post_Formats*/
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'audio',
			'quote',
			'link',
			'gallery',
		) );

		// This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );
	}
endif;
add_action( 'after_setup_theme', 'minera_action_theme_setup' );

/**
 * Extend the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Presence of header image.
 * 3. Index views.
 * 4. Full-width content layout.
 * 5. Presence of footer widgets.
 * 6. Single views.
 * 7. Featured content layout.
 *
 * @param array $classes A list of existing body class values.
 *
 * @return array The filtered body class list.
 * @internal
 */

add_filter( 'body_class', 'minera_body_classes' );
function minera_body_classes( $classes ) {
    /*! GET CURRENT THEME VERSION
    ------------------------------------------------->*/
    $classes[] = 'minera-' . wp_get_theme()->Version;

    /*! BROWSER DETECT
    ------------------------------------------------->*/
    global $is_IE, $is_edge, $is_safari, $is_iphone;

    if( $is_safari ) $classes[]     = 'safari-detected';
    elseif( $is_IE ) $classes[]     = 'ie-detected';
    elseif( $is_edge ) $classes[]   = 'edge-detected';
    elseif( $is_iphone ) $classes[] = 'iphone-detected';

    /*general header data*/
    $c_header_layout = get_theme_mod('header_layout_cfg', 'layout-1');
    $header_layout = $c_header_layout;
    
    if(function_exists('fw_get_db_post_option')){
        $pid = get_queried_object_id();
        $p_header_layout = fw_get_db_post_option($pid, 'page_header_layout');

        if(isset($p_header_layout['gadget']) && $p_header_layout['gadget'] != 'default'){
            $header_layout = $p_header_layout['gadget'];
        }
    }

    /*detect header layout*/
    if($header_layout == 'layout-6'){
        $classes[] = 'has-header-layout-6';
    }elseif($header_layout == 'layout-4'){
        $classes[] = 'has-header-layout-4';
    }

    /*has header overlay(shop single option)*/
    if($header_layout == 'layout-1' || $header_layout == 'layout-4'){
        $classes[] = 'has-header-overlay';
    }

    /*page loading*/
    if(get_theme_mod('loading', false) == true){
        $classes[] = 'is-page-loading';
    }

    /*group blog*/
    if(minera_blog()){
        $classes[] = 'group-blog';
    }

    /*woocommerce page*/
    if ( class_exists( 'WooCommerce' ) ) {
        if ( is_woocommerce() ) {
            $classes[] = 'shop-archive';
        }

        if ( is_shop() ) {
            $classes[] = 'is-shop-page';
        }
    }

    /*add class `has-shop-fullwidth`*/
    $fullwidth = 'no';
    $c_fullwidth = get_theme_mod('c_shop_full', false);
    if($c_fullwidth == true){
        $fullwidth = 'yes';
    }
    if(function_exists('FW') && is_tax()){
        $id = get_queried_object()->term_id;
        $tax_name = get_queried_object()->taxonomy;
        $p_fullwidth = fw_get_db_term_option($id, $tax_name, 'fullwidth');
        $fullwidth = $p_fullwidth;
    }
    if( 'yes' == $fullwidth && ( class_exists( 'WooCommerce' ) && is_woocommerce() ) ) {
        $classes[] = 'has-shop-fullwidth';
    }

    /*singular*/
	if ( is_singular() && ! is_front_page() ) {
		$classes[] = 'singular';
	}

    /*single product not sidebar*/
    if ( is_singular( 'product' ) ) {
		$id       = get_queried_object_id();
		$position = minera_get_sidebar_position();

        if ( 'full' == $position ) {
            $classes[] = 'shop-single-not-sidebar';
        }
    }

    /*detect single post has related post*/
    if (is_singular( 'post' )) {
        $related = (function_exists('fw_get_db_post_option') ? fw_get_db_post_option(get_the_ID(), 'p_related') : 'disable');
        if($related == 'bot'){
            $classes[] = 'has-related-posts-on-bottom';
        }
    }

    /*sticky menu*/
    if(get_theme_mod('sticky', false) == true && get_theme_mod('sticky_mobile', false) == true){
        $classes[] = 'has-mobile-sticky-menu';
    }

    /*search only product*/
    if(get_theme_mod('product_search', false) == true){
        $classes[] = 'results-only-product';
    }

    /*shop page no sidebar*/
    if(get_theme_mod('c_shop_sidebar', 'left') == 'full'){
        $classes[] = 'shop-no-sidebar';
    }

    /*header layout 2 overlay*/
    if(get_theme_mod('hd2_overlay', false) == true){
        $classes[] = 'has-header-layout-overlay';
    }

    // Theme version.
	$theme     = wp_get_theme();
	$classes[] = 'minera-' . $theme->get( 'Version' );

	return $classes;
}

/**
 * Extend the default WordPress post classes.
 *
 * Adds a post class to denote:
 * Non-password protected page with a post thumbnail.
 *
 * @param array $classes A list of existing post class values.
 *
 * @return array The filtered post class list.
 * @internal
 */
function minera_filter_theme_post_classes( $classes ) {
	if ( ! post_password_required() && ! is_attachment() && has_post_thumbnail() ) {
		$classes[] = 'has-post-thumbnail';
	}

	return $classes;
}

add_filter( 'post_class', 'minera_filter_theme_post_classes' );

/**
 * Create a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 *
 * @return string The filtered title.
 * @internal
 */
function minera_filter_theme_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() ) {
		return $title;
	}

	// Add the site name.
	$title .= get_bloginfo( 'name', 'display' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
	}

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 ) {
		$title = "$title $sep " . sprintf( esc_html__( 'Page %s', 'minera'), max( $paged, $page ) );
	}

	return $title;
}

add_filter( 'wp_title', 'minera_filter_theme_wp_title', 10, 2 );

/*Flush out the transients used in fw_theme_categorized_blog*/
function minera_action_theme_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'fw_theme_category_count' );
}
add_action( 'edit_category', 'minera_action_theme_category_transient_flusher' );
add_action( 'save_post', 'minera_action_theme_category_transient_flusher' );

/*Register widget areas*/
function minera_action_theme_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Widget Area', 'minera'),
		'id'            => 'blog-widget',
		'description'   => esc_html__( 'Appears in the blog sidebar section of the site.', 'minera'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area', 'minera'),
		'id'            => 'footer-widget',
		'description'   => esc_html__( 'Appears in the footer section of the site.', 'minera'),
		'before_widget' => '<div class="col-md-3 col-lg-3"><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside></div>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>',
	) );

	if(class_exists('Woocommerce')) {
		register_sidebar(array(
			'name' => esc_html__('Shop Widget Area', 'minera'),
			'id' => 'shop-widget',
			'description' => esc_html__('Appears in the sidebar of shop page.', 'minera'),
			'before_widget' => '<aside id="%1$s" class="widget shop %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h6 class="widget-title">',
			'after_title' => '</h6>',
		));
	}
}
add_action( 'widgets_init', 'minera_action_theme_widgets_init' );

/** Filter to wp_editor to optimize fw_resize function*/
add_filter( 'jpeg_quality', 'minera_filter_theme_image_full_quality' );
add_filter( 'wp_editor_set_quality', 'minera_filter_theme_image_full_quality' );
function minera_filter_theme_image_full_quality( $quality ) {
	return 100;
}

/*Fixed problem Unyson & YITH*/
add_action( 'admin_enqueue_scripts', 'minera_deregister_woocommerce_setting', 99 );
function minera_deregister_woocommerce_setting(){
    $screen = get_current_screen();
    if ( $screen->post_type == 'page' || $screen->post_type == 'product' ){
        wp_deregister_script( 'woocommerce_settings' );
    }
}

/*Custom css for admin*/
function minera_load_wp_admin_style() {
    /*add new column into posts admin screen*/
    wp_enqueue_style( 'minera-custom-posts-ad-screen', get_template_directory_uri() . '/css/custom.css');
    /*custom style switch control*/
    if(class_exists('Kirki')){
        wp_enqueue_style( 'minera-kirki-customizer', get_template_directory_uri() . '/css/kirki-customizer.css');
    }
    if(class_exists('WPBakeryVisualComposerAbstract')){
        /*vc-builder*/
        wp_enqueue_style( 'minera-vc-builder', get_template_directory_uri() . '/css/vc-builder.css');
        /*extend type visual composer*/
        wp_enqueue_style( 'minera-vc-extend', get_template_directory_uri() . '/css/vc-extend.css');
        /*ionicon font - for vc-builder*/
        wp_enqueue_style( 'minera-ionicons', get_template_directory_uri() . '/css/ionicons.min.css');
    }
    if(function_exists('FW')){
        /*override css from `jquery-ui.min` for unyson page options*/
        wp_enqueue_style( 'minera-override-unyson', get_template_directory_uri() . '/css/override-unyson.css');
    }
}
add_action( 'admin_enqueue_scripts', 'minera_load_wp_admin_style' );

/*Install Demo content*/
function minera_backups_demos($demos) {
	$demos_array = array(
		'minera' => array(
			'title' => esc_html__('Minera Demo', 'minera'),
			'screenshot' => get_template_directory_uri().'/screenshot.png',
			'preview_link' => '//haintheme.com/demo/wp/mirena/',
		),
	);

	$download_url = 'http://haintheme.com/ht-demos/';

	foreach ($demos_array as $id => $data) {
		$demo = new FW_Ext_Backups_Demo($id, 'piecemeal', array(
			'url' => $download_url,
			'file_id' => $id,
		));
		$demo->set_title($data['title']);
		$demo->set_screenshot($data['screenshot']);
		$demo->set_preview_link($data['preview_link']);

		$demos[ $demo->get_id() ] = $demo;

		unset($demo);
	}

	return $demos;
}
add_filter('fw:ext:backups-demo:demos', 'minera_backups_demos');

/** WooCommerce Hooks */
remove_action('woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10);
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5);
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);